pub enum PersistSuperSegmentHeadersError {
MustFollowLastSegmentIndex {
super_segment_index: SuperSegmentIndex,
last_super_segment_index: SuperSegmentIndex,
},
FirstSegmentIndexZero {
super_segment_index: SuperSegmentIndex,
},
StorageItemWriteError {
error: Error,
},
}Expand description
Variants
MustFollowLastSegmentIndex
Super segment index must strictly follow the last super segment index, can’t store super segment header
Fields

super_segment_index: SuperSegmentIndexSuper segment index that was attempted to be inserted

last_super_segment_index: SuperSegmentIndexLast super segment index
FirstSegmentIndexZero
The first super segment index must be zero
Fields

super_segment_index: SuperSegmentIndexSuper segment index that was attempted to be inserted
StorageItemWriteError
Storage item write error